@@ -28,6 +28,10 @@ Contact: yuvraaj@gmail.com
 #include <QSystemAlignedTimer>
 QTM_USE_NAMESPACE
 
+// For some reason the symbian MOC doesn't like it if I don't include QObject
+// even though it is present in QtCore which is included in global.h
+#include <QObject>
+
 class FuzzyTimerPrivate : public QObject
 {
     Q_OBJECT
