@@ -45,6 +45,14 @@ Contact: yuvraaj@gmail.com
 // even though it is present in QtCore which is included in global.h
 #include <QObject>
 
+enum LoginStatus {
+    LS_NotLoggedIn = 0,
+    LS_InProgress,      // = 1
+    LS_LoggedIn,        // = 2
+    LS_LoginFailure,    // = 3
+    LS_NwError
+};
+
 class MainWindow : public QDeclarativeView
 {
     Q_OBJECT
@@ -92,10 +100,13 @@ private slots:
     //! Called when the GV Api completes login - with success or failure
     void loginCompleted (AsyncTaskToken *token);
 
+    //! Called when the logout button is clicked
+    void doCancelLogin ();
     //! Called when the logout button is clicked
     void doLogout ();
     //! Called when the GV Api completes logoff - with success or failure
     void logoutCompleted (AsyncTaskToken *token);
+
     //! Invoked when the system ray is clicked
     void systray_activated (QSystemTrayIcon::ActivationReason reason);
 
@@ -312,12 +323,14 @@ private:
     QAction         actExit;
 
     //! Are we logged in?
-    bool            bLoggedIn;
+    LoginStatus     loginStatus;
     //! User name
     QString         strUser;
     //! Password
     QString         strPass;
 
+    AsyncTaskToken *loginTask;
+
     //! Model for registered phone numbers
     RegNumberModel *modelRegNumber;
     //! Index of the registered phone currently in use
