@@ -23,10 +23,7 @@ Contact: yuvraaj@gmail.com
 
 #if TELEPATHY_CAPABLE
 #include "TpObserver.h"
-#include <TelepathyQt4/ClientRegistrar>
-
-ClientRegistrarPtr  clientRegistrar;
-
+static ClientRegistrarPtr clientRegistrar;
 #endif
 
 #if LINUX_DESKTOP || defined(Q_WS_WIN32)
@@ -62,8 +59,7 @@ ObserverFactory::init ()
     clientRegistrar = ClientRegistrar::create();
 
     ChannelClassSpecList filters;
-    filters.append (Tp::ChannelClassSpec(
-                    TELEPATHY_INTERFACE_CHANNEL_TYPE_STREAMED_MEDIA,
+    filters.append (Tp::ChannelClassSpec(TPQT_CHANNEL_TYPE_STREAMED_MEDIA,
                     Tp::HandleTypeContact));
     TpObserver *myobserver = new TpObserver(filters, this);
     AbstractClientPtr appr = (AbstractClientPtr) myobserver;
